AssetListResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AssetListResponse$Response({required List<AssetInfoSchema> assetList})
const
AssetListResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

assetList → List<AssetInfoSchema>
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<AssetInfoSchema>? assetList}) → AssetListResponse$Response

Available on AssetListResponse$Response, provided by the $AssetListResponse$ResponseExtension extension

copyWithWrapped({Wrapped<List<AssetInfoSchema>>? assetList}) → AssetListResponse$Response

Available on AssetListResponse$Response, provided by the $AssetListResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const AssetListResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AssetListResponse$Response instance)