AssetMetaSchemaV2 class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AssetMetaSchemaV2({int? decimals, String? displayName, String? imageUrl, String? symbol})
const
AssetMetaSchemaV2.fromJson(Map<String, dynamic> json)
factory

Properties

decimals → int?
final
displayName → String?
final
hashCode → int
The hash code for this object.
no setteroverride
imageUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → String?
final

Methods

copyWith({int? decimals, String? displayName, String? imageUrl, String? symbol}) → AssetMetaSchemaV2

Available on AssetMetaSchemaV2, provided by the $AssetMetaSchemaV2Extension extension

copyWithWrapped({Wrapped<int?>? decimals, Wrapped<String?>? displayName, Wrapped<String?>? imageUrl, Wrapped<String?>? symbol}) → AssetMetaSchemaV2

Available on AssetMetaSchemaV2, provided by the $AssetMetaSchemaV2Extension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const AssetMetaSchemaV2 Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AssetMetaSchemaV2 instance)