BlockSchema class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BlockSchema({required int blockNumber, required int blockTimestamp})
const
BlockSchema.fromJson(Map<String, dynamic> json)
factory

Properties

blockNumber → int
final
blockTimestamp → int
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? blockNumber, int? blockTimestamp}) → BlockSchema

Available on BlockSchema, provided by the $BlockSchemaExtension extension

copyWithWrapped({Wrapped<int>? blockNumber, Wrapped<int>? blockTimestamp}) → BlockSchema

Available on BlockSchema, provided by the $BlockSchemaExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const BlockSchema Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BlockSchema instance)