EventSchema class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EventSchema({required BlockSchema block})
const
EventSchema.fromJson(Map<String, dynamic> json)
factory

Properties

block → BlockSchema
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BlockSchema? block}) → EventSchema

Available on EventSchema, provided by the $EventSchemaExtension extension

copyWithWrapped({Wrapped<BlockSchema>? block}) → EventSchema

Available on EventSchema, provided by the $EventSchemaExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const EventSchema Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(EventSchema instance)