EventsResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

EventsResponse$Response({required EventSchema event})
const
EventsResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

event → EventSchema
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EventSchema? event}) → EventsResponse$Response

Available on EventsResponse$Response, provided by the $EventsResponse$ResponseExtension extension

copyWithWrapped({Wrapped<EventSchema>? event}) → EventsResponse$Response

Available on EventsResponse$Response, provided by the $EventsResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const EventsResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(EventsResponse$Response instance)