FarmNftRewardInfoSchema class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FarmNftRewardInfoSchema({required String address, required String amount})
const
FarmNftRewardInfoSchema.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
final
amount → String
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? address, String? amount}) → FarmNftRewardInfoSchema

Available on FarmNftRewardInfoSchema, provided by the $FarmNftRewardInfoSchemaExtension extension

copyWithWrapped({Wrapped<String>? address, Wrapped<String>? amount}) → FarmNftRewardInfoSchema

Available on FarmNftRewardInfoSchema, provided by the $FarmNftRewardInfoSchemaExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const FarmNftRewardInfoSchema Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FarmNftRewardInfoSchema instance)