FarmResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

FarmResponse$Response({required FarmInfoSchema farm})
const
FarmResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

farm → FarmInfoSchema
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({FarmInfoSchema? farm}) → FarmResponse$Response

Available on FarmResponse$Response, provided by the $FarmResponse$ResponseExtension extension

copyWithWrapped({Wrapped<FarmInfoSchema>? farm}) → FarmResponse$Response

Available on FarmResponse$Response, provided by the $FarmResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const FarmResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(FarmResponse$Response instance)