LiquidityEvent class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LiquidityEvent({required String amount0, required String amount1, required int eventIndex, required String maker, required String pairId, Reserves? reserves, required String txnId, required int txnIndex})
const
LiquidityEvent.fromJson(Map<String, dynamic> json)
factory

Properties

amount0 → String
final
amount1 → String
final
eventIndex → int
final
hashCode → int
The hash code for this object.
no setteroverride
maker → String
final
pairId → String
final
reserves → Reserves?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txnId → String
final
txnIndex → int
final

Methods

copyWith({String? amount0, String? amount1, int? eventIndex, String? maker, String? pairId, Reserves? reserves, String? txnId, int? txnIndex}) → LiquidityEvent

Available on LiquidityEvent, provided by the $LiquidityEventExtension extension

copyWithWrapped({Wrapped<String>? amount0, Wrapped<String>? amount1, Wrapped<int>? eventIndex, Wrapped<String>? maker, Wrapped<String>? pairId, Wrapped<Reserves?>? reserves, Wrapped<String>? txnId, Wrapped<int>? txnIndex}) → LiquidityEvent

Available on LiquidityEvent, provided by the $LiquidityEventExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const LiquidityEvent Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LiquidityEvent instance)