MarketListResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

MarketListResponse$Response({required List<String> pairs})
const
MarketListResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
pairs → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? pairs}) → MarketListResponse$Response

Available on MarketListResponse$Response, provided by the $MarketListResponse$ResponseExtension extension

copyWithWrapped({Wrapped<List<String>>? pairs}) → MarketListResponse$Response

Available on MarketListResponse$Response, provided by the $MarketListResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const MarketListResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(MarketListResponse$Response instance)