OperationStatus class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OperationStatus({required String address, required String balanceDeltas, required String coins, required String exitCode, required String logicalTime, required String queryId, required String txHash})
const
OperationStatus.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
final
balanceDeltas → String
final
coins → String
final
exitCode → String
final
hashCode → int
The hash code for this object.
no setteroverride
logicalTime → String
final
queryId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txHash → String
final

Methods

copyWith({String? address, String? balanceDeltas, String? coins, String? exitCode, String? logicalTime, String? queryId, String? txHash}) → OperationStatus

Available on OperationStatus, provided by the $OperationStatusExtension extension

copyWithWrapped({Wrapped<String>? address, Wrapped<String>? balanceDeltas, Wrapped<String>? coins, Wrapped<String>? exitCode, Wrapped<String>? logicalTime, Wrapped<String>? queryId, Wrapped<String>? txHash}) → OperationStatus

Available on OperationStatus, provided by the $OperationStatusExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const OperationStatus Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(OperationStatus instance)