OperationsInfo class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OperationsInfo({required AssetInfoSchema asset0Info, required AssetInfoSchema asset1Info, required OperationStat operation})
const
OperationsInfo.fromJson(Map<String, dynamic> json)
factory

Properties

asset0Info → AssetInfoSchema
final
asset1Info → AssetInfoSchema
final
hashCode → int
The hash code for this object.
no setteroverride
operation → OperationStat
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AssetInfoSchema? asset0Info, AssetInfoSchema? asset1Info, OperationStat? operation}) → OperationsInfo

Available on OperationsInfo, provided by the $OperationsInfoExtension extension

copyWithWrapped({Wrapped<AssetInfoSchema>? asset0Info, Wrapped<AssetInfoSchema>? asset1Info, Wrapped<OperationStat>? operation}) → OperationsInfo

Available on OperationsInfo, provided by the $OperationsInfoExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const OperationsInfo Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(OperationsInfo instance)