OperationsResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

OperationsResponse$Response({required List<OperationsInfo> operations})
const
OperationsResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
operations → List<OperationsInfo>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<OperationsInfo>? operations}) → OperationsResponse$Response

Available on OperationsResponse$Response, provided by the $OperationsResponse$ResponseExtension extension

copyWithWrapped({Wrapped<List<OperationsInfo>>? operations}) → OperationsResponse$Response

Available on OperationsResponse$Response, provided by the $OperationsResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const OperationsResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(OperationsResponse$Response instance)