PoolInfoSchema class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PoolInfoSchema({required String address, String? apy1d, String? apy30d, String? apy7d, required String collectedToken0ProtocolFee, required String collectedToken1ProtocolFee, required bool deprecated, String? lpAccountAddress, String? lpBalance, required String lpFee, String? lpPriceUsd, required String lpTotalSupply, String? lpTotalSupplyUsd, String? lpWalletAddress, required String protocolFee, required String protocolFeeAddress, required String refFee, required String reserve0, required String reserve1, required String routerAddress, required String token0Address, String? token0Balance, required String token1Address, String? token1Balance})
const
PoolInfoSchema.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
final
apy1d → String?
final
apy30d → String?
final
apy7d → String?
final
collectedToken0ProtocolFee → String
final
collectedToken1ProtocolFee → String
final
deprecated → bool
final
hashCode → int
The hash code for this object.
no setteroverride
lpAccountAddress → String?
final
lpBalance → String?
final
lpFee → String
final
lpPriceUsd → String?
final
lpTotalSupply → String
final
lpTotalSupplyUsd → String?
final
lpWalletAddress → String?
final
protocolFee → String
final
protocolFeeAddress → String
final
refFee → String
final
reserve0 → String
final
reserve1 → String
final
routerAddress → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token0Address → String
final
token0Balance → String?
final
token1Address → String
final
token1Balance → String?
final

Methods

copyWith({String? address, String? apy1d, String? apy30d, String? apy7d, String? collectedToken0ProtocolFee, String? collectedToken1ProtocolFee, bool? deprecated, String? lpAccountAddress, String? lpBalance, String? lpFee, String? lpPriceUsd, String? lpTotalSupply, String? lpTotalSupplyUsd, String? lpWalletAddress, String? protocolFee, String? protocolFeeAddress, String? refFee, String? reserve0, String? reserve1, String? routerAddress, String? token0Address, String? token0Balance, String? token1Address, String? token1Balance}) → PoolInfoSchema

Available on PoolInfoSchema, provided by the $PoolInfoSchemaExtension extension

copyWithWrapped({Wrapped<String>? address, Wrapped<String?>? apy1d, Wrapped<String?>? apy30d, Wrapped<String?>? apy7d, Wrapped<String>? collectedToken0ProtocolFee, Wrapped<String>? collectedToken1ProtocolFee, Wrapped<bool>? deprecated, Wrapped<String?>? lpAccountAddress, Wrapped<String?>? lpBalance, Wrapped<String>? lpFee, Wrapped<String?>? lpPriceUsd, Wrapped<String>? lpTotalSupply, Wrapped<String?>? lpTotalSupplyUsd, Wrapped<String?>? lpWalletAddress, Wrapped<String>? protocolFee, Wrapped<String>? protocolFeeAddress, Wrapped<String>? refFee, Wrapped<String>? reserve0, Wrapped<String>? reserve1, Wrapped<String>? routerAddress, Wrapped<String>? token0Address, Wrapped<String?>? token0Balance, Wrapped<String>? token1Address, Wrapped<String?>? token1Balance}) → PoolInfoSchema

Available on PoolInfoSchema, provided by the $PoolInfoSchemaExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const PoolInfoSchema Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PoolInfoSchema instance)