PoolResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PoolResponse$Response({required PoolInfoSchema pool})
const
PoolResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
pool → PoolInfoSchema
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PoolInfoSchema? pool}) → PoolResponse$Response

Available on PoolResponse$Response, provided by the $PoolResponse$ResponseExtension extension

copyWithWrapped({Wrapped<PoolInfoSchema>? pool}) → PoolResponse$Response

Available on PoolResponse$Response, provided by the $PoolResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const PoolResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PoolResponse$Response instance)