PoolStatsResponse$Response class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PoolStatsResponse$Response({required String since, required List<PoolStats> stats, required int uniqueWalletsCount, required String until})
const
PoolStatsResponse$Response.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
since → String
final
stats → List<PoolStats>
final
uniqueWalletsCount → int
final
until → String
final

Methods

copyWith({String? since, List<PoolStats>? stats, int? uniqueWalletsCount, String? until}) → PoolStatsResponse$Response

Available on PoolStatsResponse$Response, provided by the $PoolStatsResponse$ResponseExtension extension

copyWithWrapped({Wrapped<String>? since, Wrapped<List<PoolStats>>? stats, Wrapped<int>? uniqueWalletsCount, Wrapped<String>? until}) → PoolStatsResponse$Response

Available on PoolStatsResponse$Response, provided by the $PoolStatsResponse$ResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const PoolStatsResponse$Response Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(PoolStatsResponse$Response instance)