SwapEvent class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SwapEvent({String? amount0In, String? amount0Out, String? amount1In, String? amount1Out, required int eventIndex, required String maker, required String pairId, required String priceNative, Reserves? reserves, required String txnId, required int txnIndex})
const
SwapEvent.fromJson(Map<String, dynamic> json)
factory

Properties

amount0In → String?
final
amount0Out → String?
final
amount1In → String?
final
amount1Out → String?
final
eventIndex → int
final
hashCode → int
The hash code for this object.
no setteroverride
maker → String
final
pairId → String
final
priceNative → String
final
reserves → Reserves?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
txnId → String
final
txnIndex → int
final

Methods

copyWith({String? amount0In, String? amount0Out, String? amount1In, String? amount1Out, int? eventIndex, String? maker, String? pairId, String? priceNative, Reserves? reserves, String? txnId, int? txnIndex}) → SwapEvent

Available on SwapEvent, provided by the $SwapEventExtension extension

copyWithWrapped({Wrapped<String?>? amount0In, Wrapped<String?>? amount0Out, Wrapped<String?>? amount1In, Wrapped<String?>? amount1Out, Wrapped<int>? eventIndex, Wrapped<String>? maker, Wrapped<String>? pairId, Wrapped<String>? priceNative, Wrapped<Reserves?>? reserves, Wrapped<String>? txnId, Wrapped<int>? txnIndex}) → SwapEvent

Available on SwapEvent, provided by the $SwapEventExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fromJsonFactory → const SwapEvent Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(SwapEvent instance)